Use definitions where the rate in l/ha refers to the volume of the spraying solution
Source:R/product-rates.R
l_per_ha_is_water_volume.RdThis information is used in the functions product_rates and application_rate_g_per_ha in cases where a rate in l/ha exceeds 100 l/ha. It only affects older XML files, in current versions of the XML files, rate specifications always refer to the product.
Details
Currently, the affected products are Dormex (P-Nr. 5151) and Karate with Zeon technology (P-Nr. 3756).