Learn R Programming

srppp (version 2.0.3)

units_convertible_to_g_per_ha: Product application rate units convertible to grams active substance per hectare

Description

Product application rate units convertible to grams active substance per hectare

Usage

units_convertible_to_g_per_ha

Arguments

Format

An object of class character of length 7.

See Also

application_rate_g_per_ha

Examples

Run this code
library(srppp)
library(dplyr)
# These are the convertible units
units_convertible_to_g_per_ha

Run the code above in your browser using DataLab