Learn R Programming

srppp (version 2.0.2)

l_per_ha_is_water_volume: Use definitions where the rate in l/ha refers to the volume of the spraying solution

Description

Use definitions where the rate in l/ha refers to the volume of the spraying solution

Usage

l_per_ha_is_water_volume

Arguments

Format

An object of class tbl_df (inherits from tbl, data.frame) with 1 rows and 4 columns.

See Also

application_rate_g_per_ha

Examples

Run this code
library(srppp)
l_per_ha_is_water_volume

Run the code above in your browser using DataLab